==> fengoffice_1.7.5.zip: fengoffice/language/zh_cn/project_interface.php <==
<?php return array(
	'upcoming milestones in next 30 days' => '即将到来的里程碑(今后30天内)',
	'show all upcoming milestones' => '显示所有即将到来的里程碑(总计 {0})',
	'recent activities' => '最近活动',
	'search button caption' => '搜索',
	'search result description' => '当前显示：<strong>{0}</strong>，共：<strong>{1}</strong> 个对象匹配 <strong>\\"{2}"</strong>',
	'search result description short' => '第{0}-{1}条，共：{2}条',
	'edit this file' => '编辑此文件',
	'file contents' => '文件内容',
	'important message desc' => '重要笔记在工作区的笔记页的"重要笔记"侧栏被列出',
	'important file desc' => '重要文件在文件部分的"重要文件"块中被列出',
	'enable comments' => '允许评论',
	'enable comments desc' => '用户可以查看本对象并且可以对它发布评论信息，选择"否"锁定评论。',
	'enable anonymous comments' => '匿名评论',
	'enable anonymous comments desc' => '允许匿名评论发布到本对象，匿名评论可以通过API应用程序接口或者其他外部源（如果允许）进行发布。作者必须提供一个名字和有效的电子邮件地址，来源IP地址将被记录。',
	'completed task' => '完成的任务',
	'completed tasks' => '完成的任务',
	'open task' => '打开任务',
	'open tasks' => '打开的任务',
	'view all completed tasks' => '所有已完成的任务。(总计{0})',
	'recently completed tasks' => '最近完成的任务',
	'task open of total tasks' => '列表中 {1} 任务中的 {0} 个被打开',
	'subtask of' => '<a class="internalLink" href="{0}">{1}</a>的子任务',
	'read more' => '读取更多»',
	'message separator' => '<p>* * *</p>',
	'comments on message' => '{0}条评论',
	'comment on object' => '在{1}上有{0}条评论',
	'revisions on file' => '{0} 个版本',
	'message posted on by linktitle' => '{1}发布于{0}',
	'comment posted on by linktitle' => '{1}发布于{0}',
	'message posted on by' => '在 {0} 由 <a class="internalLink" href="{1}">{2}</a>发布',
	'comment posted on' => '在 {0}',
	'comment posted on by' => '在 {0} 由 <a class="internalLink" href="{1}">{2}</a>发布',
	'completed on by' => '{0} | <a class="internalLink" href="{1}">{2}</a>',
	'started on by' => '{0} | <a class="internalLink" href="{1}">{2}</a>',
	'posted on by' => '{0} | <a class="internalLink" href="{1}">{2}</a>',
	'milestone assigned to' => '分派到 {0}',
	'assigned to' => '分派到',
	'project started on' => '开始在',
	'email sent by linktitle' => '发送了 {1}, {0}',
	'send milestone assigned to notification' => '发送里程碑电子邮件通知到用户',
	'send task assigned to notification' => '发送任务电子邮件通知到用户',
	'edit company data' => '<a class="internalLink" href="{0}">编辑</a> 公司数据',
	'company users involved in project' => '{1}涉及了 {0} 个用户',
	'companies involved in project' => '涉及的公司',
	'tags used on projects' => '本工作区使用的标签',
	'number of tagged objects' => '标记了{0}个对象',
	'total objects tagged with' => '本工作区中有<b>{0}</b>个对象被<b>{1}</b>所标记。',
	'no objects tagged with' => '本工作区中没有对象被<b>{0}</b>所标记',
	'tags widget description' => '列出以逗号分割的标签(例如: "interface, javascript, public beta")',
	'project permissions form hint' => '使用<a class="internalLink" href="{0}">权限form</a> 你可以方便的添加或者移除公司和用户以及控制他们的访问权限。',
	'expand additional text' => '展开',
	'collapse additional text' => '收缩',
	'email notification' => '电子邮件通知',
	'email notification desc' => '通知已选择订阅的人通过电子邮件接收此消息',
	'assign milestone task list desc' => '任务可以被分派到已有的里程碑',
	'link existing object' => '关联存在的对象(在文件区)',
	'upload and link' => '上传新文件并附加到这个对象。',
	'file permissions description' => '从下拉框中选择用户或者在文本框中输入他们的名字，然后使用"添加用户"使他们显示在此表格。<br>当你看到他们时，在格子中选择合适的权限。<br>注意:下拉框将只显示你和你当前共享文件的用户。',
	'subscribers desc' => '订户在其他人发布了一个评论到这个对象时将接收到一个电子邮件通知。',
	'admins can post comments on locked objects desc' => '<strong>评论已被锁定</strong>, 但是你是超级管理员，将仍然拥有发布评论的权限。注意：如果你期待你的客户和非管理员的回应，你需要为本对象解锁评论。(设置"允许评论" 选项为"是")</i>.',
	'all permissions' => '全部',
	'can manage messages' => '管理笔记',
	'can manage tasks' => '管理任务',
	'can manage milestones' => '管理里程碑',
	'can upload files' => '上传文件',
	'can manage files' => '管理文件',
	'can assign to owners' => '分派任务到我的公司成员',
	'can assign to other' => '分派任务到其他客户的成员',
	'can manage properties' => '管理属性',
	'can manage events' => '管理事件',
	'add by' => '添加者',
	'edit by' => '更新者',
	'delete by' => '删除者',
	'close by' => '关闭者',
	'open by' => '打开者',
	'upload by' => '上传者',
	'created by' => '创建者',
	'project description' => '描述信息',
	'project status' => '工作区状态',
	'show project desciption in overview' => '在工作区预览页显示描述信息?',
	'new file' => '新文件',
	'existing file' => '已有文件',
	'replace file description' => '你可以替换一个存在的文件为指定的新文件。如果你不想替换它只须使本字段为空。',
	'download history' => '下载历史',
	'download history for' => '<a class="internalLink" href="{0}">{1}</a>的下载历史',
	'downloaded by' => '下载者',
	'downloaded on' => '下载时间',
	'order by filename' => '文件名(a-z)',
	'order by posttime' => '日期和时间',
	'all files' => '全部文件',
	'upload file desc' => '你可以上传任何类型的文件，最大的文件大小是{0}',
	'file revision info short' => '版本：#{0}，<span>(创建日期：{1})</span>',
	'file revision info long' => '版本：#{0}，<span>(<a class="internalLink" href="{1}">{2}</a>创建于{3})</span>',
	'file revision title short' => '创建日期：{0}</span>',
	'file revision title long' => '<b><a class="internalLink" href="{0}">{1}</a></b> {2}',
	'file checkout info short' => '<span>签出时间：{0}</span>',
	'file checkout info long' => '<span>签出者：</span><a class="internalLink" href="{0}">{1}</a>，<span>{2}</span>',
	'update file' => '更新文件',
	'version file change' => '记住这个改变(旧文件将被保存)',
	'last revision' => '最新版本',
	'revision comment' => '版本注释',
	'edit revision comment' => '编辑版本注释',
	'initial versions' => '-- 初始化版本 --',
	'file details' => '文件详细信息',
	'view file details' => '显示文件详细信息',
	'add link object control' => '添加关联对象',
	'remove link object control' => '移除关联对象',
	'link objects to object desc' => '使用本表单来关联对象到<strong><a href="{0}">{1}</a></strong>。你可以关联一个或多个对象。你可以选择任何存在的对象或者上传一个新的。<strong>新对象在上传以后将总在文件区有效</strong>.',
	'select object' => '选择对象',
	'admin notice comments disabled' => '评论被禁用，但是你作为超级管理员仍然可以发表评论，如果你想得到其他人的回复，你必须启用评论选项为"是"。',
	'icalendar' => 'iCalendar',
	'icalendar subscribe' => 'iCalendar 订阅',
	'icalendar subscribe desc' => '使用这个链接来把你的里程碑数据带到你喜爱的日历程序中。',
	'icalendar password change notice' => '<strong>注意:</strong> 如果你改变了你的密码,链接的日历数据将也改变，你需要重新订阅。',
	'success message' => '成功消息',
	'project form action' => '项目表单操作',
	'project form action add comment' => '添加评论',
	'project form action add task' => '添加任务',
	'project form enabled' => '允许',
	'project form visible' => '可见',
	'add comment to message' => '添加评论到<a class="internalLink" href="{0}">{1}</a>',
	'add comment to message short' => '到',
	'add task to list' => '添加任务到<a class="internalLink" href="{0}">{1}</a>',
	'add task to list short' => '到',
	'private message desc' => '私有笔记仅对我的公司成员可见，客户公司成员将不能看到它们。',
	'private webpage desc' => '私有网站链接仅对我的公司成员可见，客户公司成员将不能看到它们。',
	'private milestone desc' => '私有里程碑仅对我的公司成员可见，客户公司成员将不能看到它们。',
	'private task list desc' => '私有任务仅对我的公司成员可见，客户公司成员将不能看到它们。',
	'private comment desc' => '私有评论仅对我的公司成员可见，客户公司成员将不能看到它们。',
	'private file desc' => '私有文件仅对我的公司成员可见，客户公司成员将不能看到它们。',
	'select a tag' => '选择标签...',
	'select a user' => '选择用户...',
	'select a project' => '选择工作区...',
	'upload a file' => '上传文件',
	'upload project desc' => '保存上传文件的工作区',
	'upload tag desc' => '在这里你可以选择一个关于本文件的已有的标签或者新标签。选择后按回车来添加另一个标签。',
	'upload permissions desc' => '所选用户将有权限访问本文件。键入或者选择用户名然后按回车件来保留并添加新用户。',
	'upload description desc' => '键入本文件描述信息',
	'uploading file' => '上传文件...',
	'cannot delete personal project' => '个人工作区不能被删除',
	'workspace color' => '工作区颜色',
	'workspace template' => '工作区模板',
	'color1' => '红',
	'color2' => '绿',
	'color3' => '蓝',
	'color4' => '黄',
	'color5' => '橙',
	'color6' => '粉',
	'color7' => '青',
	'color8' => '紫',
	'choose a color' => '选择颜色',
	'show more' => '显示更多',
	'show more amount' => '显示更多({0})',
	'new contact' => '新联系人',
	'work' => '工作',
	'home' => '家庭',
	'other' => '其他',
	'display' => '显示',
	'display options' => '显示选项',
	'show in project' => '在工作区显示',
	'show in project desc' => '在所选工作区的预览面板中显示这个图表',
	'show in parents' => '在父工作区显示',
	'show in parents desc' => '在所有父工作区的预览面板中显示本图表。',
	'reporting' => '报告',
	'chart' => '图表',
	'new chart' => '新图表',
	'add chart' => '添加图表',
	'edit chart' => '编辑图表',
	'delete chart' => '删除图表',
	'ObjectTypeCount' => '按照类型的对象数量',
	'TasksByDueDate' => '按照截止日排序的个人任务',
	'BudgetExecution' => '实施预算',
	'BudgetExecutionTrack' => '每月的实施预算',
	'MonthlyBudgetExecution' => '当前月的实施预算',
	'bars chart' => '条状图',
	'pie chart' => '饼图',
	'lines chart' => '线图',
	'draw chart' => '绘图',
	'chart display' => '显示',
	'bar sketch' => '速写条',
	'bar 3d' => '三维条',
	'bar glass' => '玻璃条',
	'budgeted' => '已预算的',
	'current' => '当前的',
	'executed' => '已执行',
	'not executed' => '未执行',
	'success deleted chart' => '图表“{0}”被成功删除',
	'error deleted chart' => '删除图表时发生错误',
	'task priority' => '优先级',
	'high priority' => '高',
	'normal priority' => '中',
	'low priority' => '低',
	'time estimate' => '估计时长',
	'time estimate desc' => '估计任务期间（小时）。',
	'x hours' => '{0} 小时。',
	'pending' => '待完成',
	'new task template' => '新建任务模板',
	'edit task template' => '编辑任务模板',
	'new task from template' => '从模板创建新任务',
	'save as template' => '保存为模板',
	'save template' => '保存模板',
	'delete template' => '删除模板',
	'new milestone template' => '新建程碑模板',
	'new milestone from template' => '从模板新建里程碑',
	'loading' => '加载中',
	'show all' => '显示所有',
	'unassigned' => '未分派',
	'latest comments' => '最新评论',
	'include unworked pending tasks' => '包括未工作的待完成任务',
	'unworked pending tasks' => '未工作的待完成任务',
	'assign contact to workspace desc' => '为了分派联系人到一个工作区，检查这个工作区然后填充到这个文本字段的角色中。',
	'cannot change parent workspace' => '你没有足够的访问权限来改变本工作区的父亲。',
	'cannot change parent workspace description' => '这个工作区可能是一个你没有访问权限工作区的子工作区。',
	'copy of file' => '{0} 的拷贝',
	'add subscribers desc' => '订阅所选用户到本对象。订阅的用户将接收到本对象的变动通知。',
	'add custom property' => '添加自定义属性',
	'fetch imap folders' => '获取IMAP文件夹',
	'no reports found' => '未找到 {0} 的报告',
	'remove this widget' => '移除此小工具',
	'add a new' => '新增',
	'other settings' => '其他设置',
	'incoming settings' => '收件设置',
	'default account' => '默认账户',
	'default account description' => '默认账户是指撰写邮件时使用的默认邮件账户。',
	'signature' => '签名',
	'signature description' => '签名将被添加到每封由此帐号发出的邮件的末尾。',
	'attach contents' => '附加内容',
	'set parent task' => '设置父任务',
	'add milestone change workspace warning' => '警告！这个里程碑的任务必须属于同一工作区（就像此里程碑），或者其子工作区之一。如果工作区改变，任何不遵从此规则的任务都将被移动到选定的工作区。',
	'field title' => '标题',
	'field text' => '文字',
	'field email' => '邮件',
	'field from' => '来自',
	'field to' => '发往',
	'field subject' => '主题',
	'field comment' => '评论',
	'field email2' => '邮件2',
	'field body_plain' => '正文',
	'field from_name' => '来自',
	'field firstname' => '名',
	'field lastname' => '姓',
	'field filecontent' => '内容',
	'field uid' => '唯一ID',
	'field h_address' => '家庭住址',
	'field w_address' => '工作地址',
	'field o_address' => '其他地址',
	'create task from email' => '从此邮件新建任务',
	'create task from email description' => '来自：  {1}
主题：  {0}',
	'suggested workspaces' => '建议使用的工作区',
	'mail account sender name' => '发件人名称',
	'classify mails on workspace' => '自动分类到工作区',
	'mail account permissions' => '账户权限',
	'cannot access account' => '不能访问',
	'can view account emails' => '可以读/写邮件',
	'can view account emails and edit' => '可以读/写邮件并编辑账户',
	'personal settings' => '个人设置',
	'linked main title' => '链接',
	'linked file tab' => '文件',
	'linked email tab' => '邮件',
	'linked emailunclassified tab' => '未分类邮件',
	'linked message tab' => '笔记',
	'linked contact tab' => '联系人',
	'linked comment tab' => '评论',
	'linked webpage tab' => 'Web链接',
	'linked company tab' => '公司',
	'linked milestone tab' => '里程碑',
	'linked task tab' => '任务',
	'linked event tab' => '事件',
	'update unset billing values' => '不设置账单值以更新时段',
	'update unset billing values desc' => '注意：此操作将应用新的结算值到没有值的所有时段。你确定要继续吗？',
	'mail account sender name description' => '发送邮件时，“来自”字段中所填写的名字。如果留空，将使用用户的显示名。',
	'classify mails on workspace desc' => '若选中此项，所有收发往来的邮件将自动归类到所选工作区。',
	'mail account permissions desc' => '选择谁能读/写该帐户中的电子邮件、谁能编辑通用帐户信息，谁不能访问该帐户<br/><b>注</b>：在工作区分类了的邮件，无论权限如何，总是对具有该工作区邮件访问权限的用户可读。',
	'personal settings desc' => '这些设置是正对您的各个用户的，并不会影响到访问该帐户的其他用户。',
	'apply assignee to subtasks' => '将接收人应用到子任务',
	'urgent priority' => '紧急',
	'attachment from email' => '附加到邮件“{0}”',
); ?>

==> fengoffice_2.0.0.zip: fengoffice/language/zh_cn/project_interface.php <==
<?php return array(
	'upcoming milestones in next 30 days' => '即将到来的里程碑(近30天内)',
	'show all upcoming milestones' => '显示所有即将到来的里程碑(总计 {0})',
	'recent activities' => '最近活跃的',
	'search button caption' => '搜索',
	'search result description' => '当前显示：<strong>{0}</strong>，共：<strong>{1}</strong> 个对象匹配 <strong>\\"{2}"</strong>',
	'search result description short' => '{0}，{1}个结果，关键字：{2}',
	'edit this file' => '编辑此文件',
	'file contents' => '文件内容',
	'important message desc' => '重要笔记在工作区的笔记页的"重要笔记"侧栏被列出',
	'important file desc' => '重要文件在文件部分的"重要文件"块中被列出',
	'enable comments' => '允许评论',
	'enable comments desc' => '用户可以查看本对象并且可以对它发布评论信息，选择"否"锁定评论。',
	'enable anonymous comments' => '匿名评论',
	'enable anonymous comments desc' => '允许匿名评论发布到本对象，匿名评论可以通过API应用程序接口或者其他外部源（如果允许）进行发布。作者必须提供一个名字和有效的电子邮件地址，来源IP地址将被记录。',
	'completed task' => '完成的任务',
	'completed tasks' => '完成的任务',
	'open task' => '打开任务',
	'open tasks' => '打开的任务',
	'view all completed tasks' => '所有已完成的任务。(总计{0})',
	'recently completed tasks' => '最近完成的任务',
	'task open of total tasks' => '列表中 {1} 任务中的 {0} 个被打开',
	'subtask of' => '<a class="internalLink" href="{0}">{1}</a>的子任务',
	'read more' => '读取更多»',
	'message separator' => '<p>* * *</p>',
	'comments on message' => '{0} 个评论',
	'comment on object' => '在{1}上有{0}个评论',
	'revisions on file' => '{0} 个版本',
	'message posted on by linktitle' => '{1}发布于{0}',
	'comment posted on by linktitle' => '{1}发布于{0}',
	'message posted on by' => '在 {0} 由 <a class="internalLink" href="{1}">{2}</a>发布',
	'comment posted on' => '在 {0}',
	'comment posted on by' => '在 {0} 由 <a class="internalLink" href="{1}">{2}</a>发布',
	'completed on by' => '{0} | <a class="internalLink" href="{1}">{2}</a>',
	'started on by' => '{0} | <a class="internalLink" href="{1}">{2}</a>',
	'posted on by' => '{0} | <a class="internalLink" href="{1}">{2}</a>',
	'milestone assigned to' => '分派到 {0}',
	'assigned to' => '分派到',
	'project started on' => '开始在',
	'email sent by linktitle' => '发送了 {1}, {0}',
	'send milestone assigned to notification' => '发送里程碑电子邮件通知到用户',
	'send task assigned to notification' => '发送任务电子邮件通知到用户',
	'edit company data' => '<a class="internalLink" href="{0}">编辑</a> 公司数据',
	'company users involved in project' => '{1}涉及了 {0} 个用户',
	'companies involved in project' => '涉及的公司',
	'tags used on projects' => '本工作区使用的标签',
	'number of tagged objects' => '标记了{0}个对象',
	'total objects tagged with' => '本工作区中有<b>{0}</b>个对象被<b>{1}</b>所标记。',
	'no objects tagged with' => '本工作区中没有对象被<b>{0}</b>所标记',
	'tags widget description' => '列出以逗号分割的标签(例如: "interface, javascript, public beta")',
	'project permissions form hint' => '使用<a class="internalLink" href="{0}">权限form</a> 你可以方便的添加或者移除公司和用户以及控制他们的访问权限。',
	'expand additional text' => '展开',
	'collapse additional text' => '收缩',
	'email notification' => '电子邮件通知',
	'email notification desc' => '通知已选择订阅的人通过电子邮件接收此消息',
	'assign milestone task list desc' => '任务可以被分派到已有的里程碑',
	'link existing object' => '关联存在的对象(在文件区)',
	'upload and link' => '上传新文件并附加到这个对象。',
	'file permissions description' => '从下拉框中选择用户或者在文本框中输入他们的名字，然后使用"添加用户"使他们显示在此表格。<br>当你看到他们时，在格子中选择合适的权限。<br>注意:下拉框将只显示你和你当前共享文件的用户。',
	'subscribers desc' => '订户在其他人发布了一个评论到这个对象时将接收到一个电子邮件通知。',
	'admins can post comments on locked objects desc' => '<strong>评论已被锁定</strong>, 但是你是超级管理员，将仍然拥有发布评论的权限。注意：如果你期待你的客户和非管理员的回应，你需要为本对象解锁评论。(设置"允许评论" 选项为"是")</i>.',
	'all permissions' => '全部',
	'can manage messages' => '管理笔记',
	'can manage tasks' => '管理任务',
	'can manage milestones' => '管理里程碑',
	'can upload files' => '上传文件',
	'can manage files' => '管理文件',
	'can assign to owners' => '分派任务到我的公司成员',
	'can assign to other' => '分派任务到其他客户的成员',
	'can manage properties' => '管理属性',
	'can manage events' => '管理事件',
	'add by' => '添加由',
	'edit by' => '更新者',
	'delete by' => '删除者',
	'close by' => '关闭者',
	'open by' => '打开者',
	'upload by' => '上传者',
	'created by' => '创建者',
	'project description' => '描述信息',
	'project status' => '工作区状态',
	'show project desciption in overview' => '在工作区预览页显示描述信息?',
	'new file' => '新文件',
	'existing file' => '已有文件',
	'replace file description' => '你可以替换一个存在的文件为指定的新文件。如果你不想替换它只须使本字段为空。',
	'download history' => '下载历史',
	'download history for' => '<a class="internalLink" href="{0}">{1}</a>的下载历史',
	'downloaded by' => '下载者',
	'downloaded on' => '被下载在',
	'order by filename' => '文件名(a-z)',
	'order by posttime' => '日期和时间',
	'all files' => '全部文件',
	'upload file desc' => '你可以上传任何类型的文件，最大的文件大小是{0}',
	'file revision info short' => '版本：#{0}，<span>(创建日期：{1})</span>',
	'file revision info long' => '版本：#{0}，<span>(<a class="internalLink" href="{1}">{2}</a>创建于{3})</span>',
	'file revision title short' => '创建日期：{0}</span>',
	'file revision title long' => '<b><a class="internalLink" href="{0}">{1}</a></b> 在 {2}',
	'file checkout info short' => '<span>签出时间{0}</span>',
	'file checkout info long' => '<span>签出者：</span><a class="internalLink" href="{0}">{1}</a>，<span>{2}</span>',
	'update file' => '更新文件',
	'version file change' => '记住这个改变(旧文件将被保存为一个引用)',
	'last revision' => '最后版本',
	'revision comment' => '版本注释',
	'edit revision comment' => '编辑版本注释',
	'initial versions' => '-- 初始化版本 --',
	'file details' => '文件详细信息',
	'view file details' => '显示文件详细信息',
	'add link object control' => '添加关联对象',
	'remove link object control' => '移除关联对象',
	'link objects to object desc' => '使用本表单来关联对象到<strong><a href="{0}">{1}</a></strong>。你可以关联一个或多个对象。你可以选择任何存在的对象或者上传一个新的。<strong>新对象在上传以后将总在文件区有效</strong>.',
	'select object' => '选择对象',
	'admin notice comments disabled' => '评论被禁用，但是你作为超级管理员仍然可以发表评论，如果你想得到其他人的回复，你必须启用评论选项为"是"。',
	'icalendar' => 'iCalendar',
	'icalendar subscribe' => 'iCalendar 订阅',
	'icalendar subscribe desc' => '使用这个链接来把你的里程碑数据带到你喜爱的日历程序中。',
	'icalendar password change notice' => '<strong>注意:</strong> 如果你改变了你的密码,链接的日历数据将也改变，你需要重新订阅。',
	'success message' => '成功消息',
	'project form action' => '项目表单操作',
	'project form action add comment' => '添加评论',
	'project form action add task' => '添加任务',
	'project form enabled' => '允许',
	'project form visible' => '可见',
	'add comment to message' => '添加评论到<a class="internalLink" href="{0}">{1}</a>',
	'add comment to message short' => '到',
	'add task to list' => '添加任务到<a class="internalLink" href="{0}">{1}</a>',
	'add task to list short' => '到',
	'private message desc' => '私有笔记仅对我的公司成员可见，客户公司成员将不能看到它们。',
	'private webpage desc' => '私有网站链接仅对我的公司成员可见，客户公司成员将不能看到它们。',
	'private milestone desc' => '私有里程碑仅对我的公司成员可见，客户公司成员将不能看到它们。',
	'private task list desc' => '私有任务仅对我的公司成员可见，客户公司成员将不能看到它们。',
	'private comment desc' => '私有评论仅对我的公司成员可见，客户公司成员将不能看到它们。',
	'private file desc' => '私有文件仅对我的公司成员可见，客户公司成员将不能看到它们。',
	'select a tag' => '选择标签...',
	'select a user' => '选择用户...',
	'select a project' => '选择工作区...',
	'upload a file' => '上传文件',
	'upload project desc' => '保存上传文件的工作区',
	'upload tag desc' => '在这里你可以选择一个关于本文件的已有的标签或者新标签。选择后按回车来添加另一个标签。',
	'upload permissions desc' => '所选用户将有权限访问本文件。键入或者选择用户名然后按回车件来保留并添加新用户。',
	'upload description desc' => '键入本文件描述信息',
	'uploading file' => '上传文件...',
	'cannot delete personal project' => '个人工作区不能被删除',
	'workspace color' => '工作区颜色',
	'workspace template' => '工作区模板',
	'color1' => '红',
	'color2' => '绿',
	'color3' => '蓝',
	'color4' => '黄',
	'color5' => '桔色',
	'color6' => '粉',
	'color7' => '青',
	'color8' => '紫',
	'choose a color' => '选择颜色',
	'show more' => '显示更多',
	'show more amount' => '显示更多的({0})个',
	'new contact' => '新联系人',
	'work' => '工作',
	'home' => '家庭',
	'other' => '其他',
	'display' => '显示',
	'display options' => '显示选项',
	'show in project' => '在工作区显示',
	'show in project desc' => '在所选工作区的预览面板中显示这个图表',
	'show in parents' => '在父工作区显示',
	'show in parents desc' => '在所有父工作区的预览面板中显示本图表。',
	'reporting' => '报告',
	'chart' => '图表',
	'new chart' => '新图表',
	'add chart' => '添加图表',
	'edit chart' => '编辑图表',
	'delete chart' => '删除图表',
	'ObjectTypeCount' => '按照类型的对象数量',
	'TasksByDueDate' => '按照截止日排序的个人任务',
	'BudgetExecution' => '实施预算',
	'BudgetExecutionTrack' => '每月的实施预算',
	'MonthlyBudgetExecution' => '当前月的实施预算',
	'bars chart' => '条状图',
	'pie chart' => '饼图',
	'lines chart' => '线图',
	'draw chart' => '绘图',
	'chart display' => '显示',
	'bar sketch' => '速写条',
	'bar 3d' => '三维条',
	'bar glass' => '玻璃条',
	'budgeted' => '已预算的',
	'current' => '当前的',
	'executed' => '已实行',
	'not executed' => '未实行',
	'success deleted chart' => '图表“{0}”成功删除',
	'error deleted chart' => '删除图表时发生错误',
	'task priority' => '优先级',
	'high priority' => '高',
	'normal priority' => '中',
	'low priority' => '低',
	'time estimate' => '估计时长',
	'time estimate desc' => '估计以小时为单位的的任务时长。',
	'x hours' => '{0} 小时。',
	'pending' => '待完成',
	'new task template' => '新任务模板',
	'edit task template' => '编辑任务模板',
	'new task from template' => '从模板创建新任务',
	'save as template' => '保存为模板',
	'save template' => '保存模板',
	'delete template' => '删除模板',
	'new milestone template' => '新里程碑模板',
	'new milestone from template' => '从模板创建新里程碑',
	'loading' => '加载中',
	'show all' => '显示所有',
	'unassigned' => '未分派',
	'latest comments' => '最新评论',
	'include unworked pending tasks' => '包括未工作的待完成任务',
	'unworked pending tasks' => '未工作的待完成任务',
	'assign contact to workspace desc' => '为了分派联系人到一个工作区，检查这个工作区然后填充到这个文本字段的角色中。',
	'cannot change parent workspace' => '你没有足够的访问权限来改变本工作区的父亲。',
	'cannot change parent workspace description' => '这个工作区可能是一个你没有访问权限工作区的子工作区。',
	'copy of file' => '{0} 的拷贝',
	'add subscribers desc' => '订阅所选用户到本对象。订阅的用户将接收到本对象的变动通知。',
	'add custom property' => '添加自定义属性',
	'fetch imap folders' => '获取IMAP文件夹',
	'no reports found' => '未找到 {0} 的报告',
	'remove this widget' => '移除此小工具',
	'add a new' => '新增',
	'other settings' => '其他设置',
	'incoming settings' => '收件设置',
	'default account' => '默认账户',
	'default account description' => '默认账户是指撰写邮件时使用的默认邮件账户。',
	'signature' => '签名',
	'signature description' => '签名将被添加到每封由此帐号发出的邮件的末尾。',
	'attach contents' => '附加内容',
	'set parent task' => '设置父任务',
	'add milestone change workspace warning' => '警告！这个里程碑的任务必须属于同一工作区（就像此里程碑），或者其子工作区之一。如果工作区改变，任何不遵从此规则的任务都将被移动到选定的工作区。',
	'field title' => '标题',
	'field text' => '文字',
	'field email' => '邮件',
	'field from' => '来自',
	'field to' => '发往',
	'field subject' => '主题',
	'field comment' => '评论',
	'field email2' => '邮件2',
	'field body_plain' => '正文',
	'field from_name' => '来自',
	'field firstname' => '名',
	'field lastname' => '姓',
	'field filecontent' => '文件内容',
	'field uid' => '唯一ID号',
	'field h_address' => '家庭住址',
	'field w_address' => '工作地址',
	'field o_address' => '其他地址',
	'create task from email' => '从此邮件新建任务',
	'create task from email description' => '来自：  {1}
主题：  {0}',
	'suggested workspaces' => '建议使用的工作区',
	'mail account sender name' => '发件人名称',
	'classify mails on workspace' => '自动分类到工作区',
	'mail account permissions' => '账户权限',
	'cannot access account' => '不能访问',
	'can view account emails' => '可以读/写邮件',
	'can view account emails and edit' => '可以读/写邮件并编辑账户',
	'personal settings' => '个人设置',
	'linked main title' => '链接',
	'linked file tab' => '文件',
	'linked email tab' => '邮件',
	'linked emailunclassified tab' => '未分类邮件',
	'linked message tab' => '笔记',
	'linked contact tab' => '联系人',
	'linked comment tab' => '评论',
	'linked webpage tab' => 'Web链接',
	'linked company tab' => '公司',
	'linked milestone tab' => '里程碑',
	'linked task tab' => '任务',
	'linked event tab' => '事件',
	'update unset billing values' => '不设置账单值以更新时段',
	'update unset billing values desc' => 'NOTICE: This action will apply the new billing values to all timeslots without values. Are you sure you wish to proceed?',
	'mail account sender name description' => 'Name to use as "From" field when sending email. If left blank the user\'s display name will be used.',
	'classify mails on workspace desc' => 'If selected, all email sent to or from this account will be automatically classified to the selected workspace.',
	'mail account permissions desc' => 'Choose who will be able to read/write emails from this account, who will be able to edit general account information and who will have no access to the account.<br/><b>Note</b>: Email classified on a workspace will always be readable by all users that can read email on that workspace, regardless of these permissions. ',
	'personal settings desc' => 'These settings are specific to your user and don\'t affect other users with access to this account.',
	'apply assignee to subtasks' => '将接收人应用到子任务',
	'urgent priority' => '紧急',
	'attachment from email' => '附加到邮件“{0}”',
); ?>
